@@ -51,13 +51,14 @@ def upload_configs(  # noqa: D
     branch: Optional[str] = None,
     commit: Optional[str] = None,
     config_dir: Optional[str] = None,
+    api_url: Optional[str] = None,
 ) -> requests.Response:
     yaml_files = read_config_files(config_dir or ".")
     results = {"yaml_files": yaml_files}
     logger.info(f"Files to upload: {yaml_files.keys()}")
     headers = {"Content-Type": "application/json", "Authorization": f"X-Api-Key {api_key}"}
 
-    add_files_url = f"https://{TRANSFORM_API_URL}/api/v1/model/{repo}/{branch}/{commit}/add_model_files"
+    add_files_url = f"https://{api_url or TRANSFORM_API_URL}/api/v1/model/{repo}/{branch}/{commit}/add_model_files"
     logger.info(f"add_files_url: {add_files_url}")
     logger.info("Uploading config files")
     r = requests.post(add_files_url, data=json.dumps(results).encode("utf-8"), headers=headers)
@@ -65,7 +66,7 @@ def upload_configs(  # noqa: D
         raise Exception(f"Failed uploading config yaml files. Error: {r.text}")
 
     if mode == UPLOAD_MODE_VALIDATE:
-        validate_url = f"https://{TRANSFORM_API_URL}/api/v1/model/{repo}/{branch}/{commit}/validate_model"
+        validate_url = f"https://{api_url or TRANSFORM_API_URL}/api/v1/model/{repo}/{branch}/{commit}/validate_model"
         logger.info(f"validate_url: {validate_url}")
         logger.info("Checking that uploaded configs are valid and form a valid model")
         r = requests.post(validate_url, headers=headers)
@@ -73,7 +74,7 @@ def upload_configs(  # noqa: D
             raise Exception(f"Failed validating uploaded configs. Error response: {r.text}")
         logger.info("Successfully validated configs")
     elif mode == UPLOAD_MODE_COMMIT:
-        commit_url = f"https://{TRANSFORM_API_URL}/api/v1/model/{repo}/{branch}/{commit}/commit_model"
+        commit_url = f"https://{api_url or TRANSFORM_API_URL}/api/v1/model/{repo}/{branch}/{commit}/commit_model"
         logger.info(f"commit_url: {commit_url}")
         logger.info("Committing model")
         r = requests.post(commit_url, headers=headers)
